---
name: Test
about: Specify a test that needs to be implemented
title: ''
labels: Testing

---

**Which module and class/method/function does this relate to?**
Please provide the module and class, method or function name(s) that the tests will apply to.

**What aspect requires additional tests?**
Please provide a description of the specifics of the test - what is the behaviour that the tests will inspect.  Ideally this will include a description of the setup (e.g. Pytest fixtures) and the expected results.

**Is this a unit, system or functional test?**
Simply state what type of test you are expecting is required.

**Additional context**
Add any other context about the tests here.
